==> grandorgue_3.12.2.orig.tar.gz: grandorgue-3.12.2-1/src/grandorgue/model/GODivisionalCoupler.cpp <==
/*
 * Copyright 2006 Milan Digital Audio LLC
 * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
 * License GPL-2.0 or later
 * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
 */

#include "GODivisionalCoupler.h"

#include <wx/intl.h>

#include "config/GOConfigReader.h"

#include "GOOrganModel.h"

GODivisionalCoupler::GODivisionalCoupler(GOOrganModel &organModel)
  : GODrawstop(organModel), m_BiDirectionalCoupling(false), m_manuals(0) {}

void GODivisionalCoupler::Load(GOConfigReader &cfg, wxString group) {
  wxString buffer;

  m_BiDirectionalCoupling
    = cfg.ReadBoolean(ODFSetting, group, wxT("BiDirectionalCoupling"));
  unsigned NumberOfManuals = cfg.ReadInteger(
    ODFSetting,
    group,
    wxT("NumberOfManuals"),
    1,
    r_OrganModel.GetManualAndPedalCount() - r_OrganModel.GetFirstManualIndex()
      + 1);

  m_manuals.resize(0);
  for (unsigned i = 0; i < NumberOfManuals; i++) {
    buffer.Printf(wxT("Manual%03d"), i + 1);
    m_manuals.push_back(cfg.ReadInteger(
      ODFSetting,
      group,
      buffer,
      r_OrganModel.GetFirstManualIndex(),
      r_OrganModel.GetManualAndPedalCount()));
  }
  GODrawstop::Load(cfg, group);
}

void GODivisionalCoupler::SetupIsToStoreInCmb() {
  m_IsToStoreInDivisional = false;
  m_IsToStoreInGeneral = r_OrganModel.GeneralsStoreDivisionalCouplers();
}

void GODivisionalCoupler::ChangeState(bool on) {}

unsigned GODivisionalCoupler::GetNumberOfManuals() { return m_manuals.size(); }

unsigned GODivisionalCoupler::GetManual(unsigned index) {
  return m_manuals[index];
}

bool GODivisionalCoupler::IsBidirectional() { return m_BiDirectionalCoupling; }

wxString GODivisionalCoupler::GetMidiType() { return _("Divisional Coupler"); }

==> grandorgue_3.13.1.orig.tar.gz: grandorgue-3.13.1-1/src/grandorgue/model/GODivisionalCoupler.cpp <==
/*
 * Copyright 2006 Milan Digital Audio LLC
 * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
 * License GPL-2.0 or later
 * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
 */

#include "GODivisionalCoupler.h"

#include <wx/intl.h>

#include "config/GOConfigReader.h"

#include "GOOrganModel.h"

GODivisionalCoupler::GODivisionalCoupler(GOOrganModel &organModel)
  : GODrawstop(organModel), m_BiDirectionalCoupling(false), m_manuals(0) {}

void GODivisionalCoupler::Load(GOConfigReader &cfg, wxString group) {
  wxString buffer;

  m_BiDirectionalCoupling
    = cfg.ReadBoolean(ODFSetting, group, wxT("BiDirectionalCoupling"));
  unsigned NumberOfManuals = cfg.ReadInteger(
    ODFSetting,
    group,
    wxT("NumberOfManuals"),
    1,
    r_OrganModel.GetManualAndPedalCount() - r_OrganModel.GetFirstManualIndex()
      + 1);

  m_manuals.resize(0);
  for (unsigned i = 0; i < NumberOfManuals; i++) {
    buffer.Printf(wxT("Manual%03d"), i + 1);
    m_manuals.push_back(cfg.ReadInteger(
      ODFSetting,
      group,
      buffer,
      r_OrganModel.GetFirstManualIndex(),
      r_OrganModel.GetManualAndPedalCount()));
  }
  GODrawstop::Load(cfg, group);
}

void GODivisionalCoupler::SetupIsToStoreInCmb() {
  m_IsToStoreInDivisional = false;
  m_IsToStoreInGeneral = r_OrganModel.GeneralsStoreDivisionalCouplers();
}

void GODivisionalCoupler::ChangeState(bool on) {}

unsigned GODivisionalCoupler::GetNumberOfManuals() { return m_manuals.size(); }

unsigned GODivisionalCoupler::GetManual(unsigned index) {
  return m_manuals[index];
}

bool GODivisionalCoupler::IsBidirectional() { return m_BiDirectionalCoupling; }

const wxString WX_MIDI_TYPE_CODE = wxT("DivisionalCoupler");
const wxString WX_MIDI_TYPE = _("Divisional Coupler");

const wxString &GODivisionalCoupler::GetMidiTypeCode() const {
  return WX_MIDI_TYPE_CODE;
}

const wxString &GODivisionalCoupler::GetMidiType() const {
  return WX_MIDI_TYPE;
}
